Мы делаем библиотеку для кластерного анализа для аналитиков с полным пайплайном (предобработка, pca, выбор фичей, визуализации, получение результатов, подбор числа кластеров и алгоритм кластеризации и т.д.).

Мы делаем удобную библиотеку и мы должны придумать удобную для использования инфраструктуру с настраиваемыми шагами через параметры. 

Я делал ресерч недавно и вот такой код у меня был в @for_developing/for_developing.py. На него не надо ориентироваться как на истину в последней инстанции - там есть дублирование логики, некоторые лишние штуки в коде - seo_segments например - плюс там может быть не хватает гибкости где-то. 

Мы хотим сделать чтобы кластеризацию можно было сделать удобно - просто один раз передав туда датафрейм наш и далее донастраивая шаги но не писать прям код самим. Плюс там визуализаций много - наверное они в нашей либе должны быть отдельно, дабы при установке не было зависимости от библиотек построения графиков (я не уверен и хотелось бы твое мнение. )

Весь код мы пишем на английском языке, всю документацию или комментарии тоже пишем на английском языке! 

Репозиторий будет тут https://github.com/alexeiveselov92/clustertk. - на PyPi будет называться библиотека clustertk - я проверил, такое название свободно.